# Dev Tool

Simple script runner that organizes and executes your development scripts. Builds itself automatically.

## Quick Start

```bash
git clone https://git.mz.uy/marianozunino/dev
cd dev
./dev
```

## Usage

```bash
./dev ls               # List all scripts
./dev run base         # Run specific script
./dev run docker       # Run scripts matching "docker"
./dev run base -- arg  # Pass arguments to script
./dev new backup       # Create new script template
./dev push             # Commit, scan, and push to git
./dev deps             # Check dependencies
./dev completion bash  # Generate shell completion
```

## How It Works

1. Put executable scripts in `runs/`
2. Run them with `./dev run <name>`
3. Check logs in `logs/`

The `./dev` wrapper automatically builds the Go binary when needed.

## Requirements

- Linux
- Go: `sudo pacman -S go` (or your distro's package manager)

## File Structure

```
project/
├── dev*           # Launcher script
├── main.go        # Source code
├── bin/           # Built binaries
├── runs/          # Your scripts go here
└── logs/          # Execution logs
```

## Features

- Auto-detects executable scripts in `runs/`
- Tab completion for script names
- Automatic logging to `logs/`
- Git integration with security scanning (GitLeaks)
- Dependency checking
- Cross-platform binary building
- Shell completion support

That's it! Clone and run `./dev` to get started.
